# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
from __future__ import annotations
"""
This file contains the exact signatures for all functions in module
PySide6.QtWebEngineCore, except for defaults which are replaced by "...".
"""

# Module `PySide6.QtWebEngineCore`

import PySide6.QtWebEngineCore
import PySide6.QtCore
import PySide6.QtGui
import PySide6.QtNetwork
import PySide6.QtWebChannel

import enum
import typing
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


NoneType: typing.TypeAlias = type[None]
PlaceHolderType = typing.TypeVar("PlaceHolderType", bound=PySide6.QtCore.QObject)


class QIntList(object): ...


class QWebEngineCertificateError(Shiboken.Object):

    class Type(enum.Enum):

        SslObsoleteVersion       : QWebEngineCertificateError.Type = ... # -0xda
        CertificateKnownInterceptionBlocked: QWebEngineCertificateError.Type = ... # -0xd9
        CertificateSymantecLegacy: QWebEngineCertificateError.Type = ... # -0xd7
        CertificateTransparencyRequired: QWebEngineCertificateError.Type = ... # -0xd6
        CertificateValidityTooLong: QWebEngineCertificateError.Type = ... # -0xd5
        CertificateNameConstraintViolation: QWebEngineCertificateError.Type = ... # -0xd4
        CertificateWeakKey       : QWebEngineCertificateError.Type = ... # -0xd3
        CertificateNonUniqueName : QWebEngineCertificateError.Type = ... # -0xd2
        CertificateWeakSignatureAlgorithm: QWebEngineCertificateError.Type = ... # -0xd0
        CertificateInvalid       : QWebEngineCertificateError.Type = ... # -0xcf
        CertificateRevoked       : QWebEngineCertificateError.Type = ... # -0xce
        CertificateUnableToCheckRevocation: QWebEngineCertificateError.Type = ... # -0xcd
        CertificateNoRevocationMechanism: QWebEngineCertificateError.Type = ... # -0xcc
        CertificateContainsErrors: QWebEngineCertificateError.Type = ... # -0xcb
        CertificateAuthorityInvalid: QWebEngineCertificateError.Type = ... # -0xca
        CertificateDateInvalid   : QWebEngineCertificateError.Type = ... # -0xc9
        CertificateCommonNameInvalid: QWebEngineCertificateError.Type = ... # -0xc8
        SslPinnedKeyNotInCertificateChain: QWebEngineCertificateError.Type = ... # -0x96


    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineCertificateError) -> None: ...

    @staticmethod
    def __copy__() -> None: ...
    def acceptCertificate(self) -> None: ...
    def certificateChain(self) -> typing.List[PySide6.QtNetwork.QSslCertificate]: ...
    def defer(self) -> None: ...
    def description(self) -> str: ...
    def isMainFrame(self) -> bool: ...
    def isOverridable(self) -> bool: ...
    def rejectCertificate(self) -> None: ...
    def type(self) -> PySide6.QtWebEngineCore.QWebEngineCertificateError.Type: ...
    def url(self) -> PySide6.QtCore.QUrl: ...


class QWebEngineClientCertificateSelection(Shiboken.Object):

    def __init__(self, arg__1: PySide6.QtWebEngineCore.QWebEngineClientCertificateSelection) -> None: ...

    @staticmethod
    def __copy__() -> None: ...
    def certificates(self) -> typing.List[PySide6.QtNetwork.QSslCertificate]: ...
    def host(self) -> PySide6.QtCore.QUrl: ...
    def select(self, certificate: PySide6.QtNetwork.QSslCertificate | PySide6.QtCore.QIODevice) -> None: ...
    def selectNone(self) -> None: ...


class QWebEngineClientCertificateStore(Shiboken.Object):
    def add(self, certificate: PySide6.QtNetwork.QSslCertificate | PySide6.QtCore.QIODevice, privateKey: PySide6.QtNetwork.QSslKey | int) -> None: ...
    def certificates(self) -> typing.List[PySide6.QtNetwork.QSslCertificate]: ...
    def clear(self) -> None: ...
    def remove(self, certificate: PySide6.QtNetwork.QSslCertificate | PySide6.QtCore.QIODevice) -> None: ...


class QWebEngineClientHints(PySide6.QtCore.QObject):
    def arch(self) -> str: ...
    def bitness(self) -> str: ...
    def fullVersion(self) -> str: ...
    def fullVersionList(self) -> typing.Dict[str, typing.Any]: ...
    def isAllClientHintsEnabled(self) -> bool: ...
    def isMobile(self) -> bool: ...
    def isWow64(self) -> bool: ...
    def model(self) -> str: ...
    def platform(self) -> str: ...
    def platformVersion(self) -> str: ...
    def qt_qmlMarker_uncreatable(self) -> None: ...
    def resetAll(self) -> None: ...
    def setAllClientHintsEnabled(self, enabled: bool) -> None: ...
    def setArch(self, arg__1: str) -> None: ...
    def setBitness(self, arg__1: str) -> None: ...
    def setFullVersion(self, arg__1: str) -> None: ...
    def setFullVersionList(self, arg__1: typing.Dict[str, typing.Any]) -> None: ...
    def setIsMobile(self, arg__1: bool) -> None: ...
    def setIsWow64(self, arg__1: bool) -> None: ...
    def setModel(self, arg__1: str) -> None: ...
    def setPlatform(self, arg__1: str) -> None: ...
    def setPlatformVersion(self, arg__1: str) -> None: ...


class QWebEngineContextMenuRequest(PySide6.QtCore.QObject):

    class EditFlag(enum.Flag):

        CanUndo                  : QWebEngineContextMenuRequest.EditFlag = ... # 0x1
        CanRedo                  : QWebEngineContextMenuRequest.EditFlag = ... # 0x2
        CanCut                   : QWebEngineContextMenuRequest.EditFlag = ... # 0x4
        CanCopy                  : QWebEngineContextMenuRequest.EditFlag = ... # 0x8
        CanPaste                 : QWebEngineContextMenuRequest.EditFlag = ... # 0x10
        CanDelete                : QWebEngineContextMenuRequest.EditFlag = ... # 0x20
        CanSelectAll             : QWebEngineContextMenuRequest.EditFlag = ... # 0x40
        CanTranslate             : QWebEngineContextMenuRequest.EditFlag = ... # 0x80
        CanEditRichly            : QWebEngineContextMenuRequest.EditFlag = ... # 0x100

    class MediaFlag(enum.Flag):

        MediaInError             : QWebEngineContextMenuRequest.MediaFlag = ... # 0x1
        MediaPaused              : QWebEngineContextMenuRequest.MediaFlag = ... # 0x2
        MediaMuted               : QWebEngineContextMenuRequest.MediaFlag = ... # 0x4
        MediaLoop                : QWebEngineContextMenuRequest.MediaFlag = ... # 0x8
        MediaCanSave             : QWebEngineContextMenuRequest.MediaFlag = ... # 0x10
        MediaHasAudio            : QWebEngineContextMenuRequest.MediaFlag = ... # 0x20
        MediaCanToggleControls   : QWebEngineContextMenuRequest.MediaFlag = ... # 0x40
        MediaControls            : QWebEngineContextMenuRequest.MediaFlag = ... # 0x80
        MediaCanPrint            : QWebEngineContextMenuRequest.MediaFlag = ... # 0x100
        MediaCanRotate           : QWebEngineContextMenuRequest.MediaFlag = ... # 0x200

    class MediaType(enum.Enum):

        MediaTypeNone            : QWebEngineContextMenuRequest.MediaType = ... # 0x0
        MediaTypeImage           : QWebEngineContextMenuRequest.MediaType = ... # 0x1
        MediaTypeVideo           : QWebEngineContextMenuRequest.MediaType = ... # 0x2
        MediaTypeAudio           : QWebEngineContextMenuRequest.MediaType = ... # 0x3
        MediaTypeCanvas          : QWebEngineContextMenuRequest.MediaType = ... # 0x4
        MediaTypeFile            : QWebEngineContextMenuRequest.MediaType = ... # 0x5
        MediaTypePlugin          : QWebEngineContextMenuRequest.MediaType = ... # 0x6


    def editFlags(self) -> PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.EditFlag: ...
    def isAccepted(self) -> bool: ...
    def isContentEditable(self) -> bool: ...
    def linkText(self) -> str: ...
    def linkUrl(self) -> PySide6.QtCore.QUrl: ...
    def mediaFlags(self) -> PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.MediaFlag: ...
    def mediaType(self) -> PySide6.QtWebEngineCore.QWebEngineContextMenuRequest.MediaType: ...
    def mediaUrl(self) -> PySide6.QtCore.QUrl: ...
    def misspelledWord(self) -> str: ...
    def position(self) -> PySide6.QtCore.QPoint: ...
    def selectedText(self) -> str: ...
    def setAccepted(self, accepted: bool) -> None: ...
    def spellCheckerSuggestions(self) -> typing.List[str]: ...


class QWebEngineCookieStore(PySide6.QtCore.QObject):

    cookieAdded              : typing.ClassVar[Signal] = ... # cookieAdded(QNetworkCookie)
    cookieRemoved            : typing.ClassVar[Signal] = ... # cookieRemoved(QNetworkCookie)

    class FilterRequest(Shiboken.Object):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, FilterRequest: PySide6.QtWebEngineCore.QWebEngineCookieStore.FilterRequest) -> None: ...

        @staticmethod
        def __copy__() -> None: ...


    def deleteAllCookies(self) -> None: ...
    def deleteCookie(self, cookie: PySide6.QtNetwork.QNetworkCookie, origin: PySide6.QtCore.QUrl | str= ...) -> None: ...
    def deleteSessionCookies(self) -> None: ...
    def loadAllCookies(self) -> None: ...
    def setCookie(self, cookie: PySide6.QtNetwork.QNetworkCookie, origin: PySide6.QtCore.QUrl | str= ...) -> None: ...
    def setCookieFilter(self, filterCallback: typing.Callable) -> None: ...


class FilterRequest(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, FilterRequest: PySide6.QtWebEngineCore.QWebEngineCookieStore.FilterRequest) -> None: ...

    @staticmethod
    def __copy__() -> None: ...


class QWebEngineDownloadRequest(PySide6.QtCore.QObject):

    downloadDirectoryChanged : typing.ClassVar[Signal] = ... # downloadDirectoryChanged()
    downloadFileNameChanged  : typing.ClassVar[Signal] = ... # downloadFileNameChanged()
    interruptReasonChanged   : typing.ClassVar[Signal] = ... # interruptReasonChanged()
    isFinishedChanged        : typing.ClassVar[Signal] = ... # isFinishedChanged()
    isPausedChanged          : typing.ClassVar[Signal] = ... # isPausedChanged()
    receivedBytesChanged     : typing.ClassVar[Signal] = ... # receivedBytesChanged()
    savePageFormatChanged    : typing.ClassVar[Signal] = ... # savePageFormatChanged()
    stateChanged             : typing.ClassVar[Signal] = ... # stateChanged(QWebEngineDownloadRequest::DownloadState)
    totalBytesChanged        : typing.ClassVar[Signal] = ... # totalBytesChanged()

    class DownloadInterruptReason(enum.Enum):

        NoReason                 : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x0
        FileFailed               : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x1
        FileAccessDenied         : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x2
        FileNoSpace              : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x3
        FileNameTooLong          : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x5
        FileTooLarge             : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x6
        FileVirusInfected        : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x7
        FileTransientError       : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0xa
        FileBlocked              : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0xb
        FileSecurityCheckFailed  : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0xc
        FileTooShort             : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0xd
        FileHashMismatch         : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0xe
        NetworkFailed            : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x14
        NetworkTimeout           : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x15
        NetworkDisconnected      : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x16
        NetworkServerDown        : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x17
        NetworkInvalidRequest    : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x18
        ServerFailed             : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x1e
        ServerBadContent         : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x21
        ServerUnauthorized       : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x22
        ServerCertProblem        : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x23
        ServerForbidden          : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x24
        ServerUnreachable        : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x25
        UserCanceled             : QWebEngineDownloadRequest.DownloadInterruptReason = ... # 0x28

    class DownloadState(enum.Enum):

        DownloadRequested        : QWebEngineDownloadRequest.DownloadState = ... # 0x0
        DownloadInProgress       : QWebEngineDownloadRequest.DownloadState = ... # 0x1
        DownloadCompleted        : QWebEngineDownloadRequest.DownloadState = ... # 0x2
        DownloadCancelled        : QWebEngineDownloadRequest.DownloadState = ... # 0x3
        DownloadInterrupted      : QWebEngineDownloadRequest.DownloadState = ... # 0x4

    class SavePageFormat(enum.Enum):

        UnknownSaveFormat        : QWebEngineDownloadRequest.SavePageFormat = ... # -0x1
        SingleHtmlSaveFormat     : QWebEngineDownloadRequest.SavePageFormat = ... # 0x0
        CompleteHtmlSaveFormat   : QWebEngineDownloadRequest.SavePageFormat = ... # 0x1
        MimeHtmlSaveFormat       : QWebEngineDownloadRequest.SavePageFormat = ... # 0x2


    def accept(self) -> None: ...
    def cancel(self) -> None: ...
    def downloadDirectory(self) -> str: ...
    def downloadFileName(self) -> str: ...
    def id(self) -> int: ...
    def interruptReason(self) -> PySide6.QtWebEngineCore.QWebEngineDownloadRequest.DownloadInterruptReason: ...
    def interruptReasonString(self) -> str: ...
    def isFinished(self) -> bool: ...
    def isPaused(self) -> bool: ...
    def isSavePageDownload(self) -> bool: ...
    def mimeType(self) -> str: ...
    def page(self) -> PySide6.QtWebEngineCore.QWebEnginePage: ...
    def pause(self) -> None: ...
    def receivedBytes(self) -> int: ...
    def resume(self) -> None: ...
    def savePageFormat(self) -> PySide6.QtWebEngineCore.QWebEngineDownloadRequest.SavePageFormat: ...
    def setDownloadDirectory(self, directory: str) -> None: ...
    def setDownloadFileName(self, fileName: str) -> None: ...
    def setSavePageFormat(self, format: PySide6.QtWebEngineCore.QWebEngineDownloadRequest.SavePageFormat) -> None: ...
    def state(self) -> PySide6.QtWebEngineCore.QWebEngineDownloadRequest.DownloadState: ...
    def suggestedFileName(self) -> str: ...
    def totalBytes(self) -> int: ...
    def url(self) -> PySide6.QtCore.QUrl: ...


class QWebEngineFileSystemAccessRequest(Shiboken.Object):

    class AccessFlag(enum.Flag):

        Read                     : QWebEngineFileSystemAccessRequest.AccessFlag = ... # 0x1
        Write                    : QWebEngineFileSystemAccessRequest.AccessFlag = ... # 0x2

    class HandleType(enum.Enum):

        File                     : QWebEngineFileSystemAccessRequest.HandleType = ... # 0x0
        Directory                : QWebEngineFileSystemAccessRequest.HandleType = ... # 0x1


    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest) -> None: ...

    @staticmethod
    def __copy__() -> None: ...
    def accept(self) -> None: ...
    def accessFlags(self) -> PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.AccessFlag: ...
    def filePath(self) -> PySide6.QtCore.QUrl: ...
    def handleType(self) -> PySide6.QtWebEngineCore.QWebEngineFileSystemAccessRequest.HandleType: ...
    def origin(self) -> PySide6.QtCore.QUrl: ...
    def reject(self) -> None: ...


class QWebEngineFindTextResult(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineFindTextResult) -> None: ...

    @staticmethod
    def __copy__() -> None: ...
    def activeMatch(self) -> int: ...
    def numberOfMatches(self) -> int: ...


class QWebEngineFullScreenRequest(Shiboken.Object):

    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineFullScreenRequest) -> None: ...

    @staticmethod
    def __copy__() -> None: ...
    def accept(self) -> None: ...
    def origin(self) -> PySide6.QtCore.QUrl: ...
    def reject(self) -> None: ...
    def toggleOn(self) -> bool: ...


class QWebEngineGlobalSettings(Shiboken.Object):

    class DnsMode(Shiboken.Object):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, DnsMode: PySide6.QtWebEngineCore.QWebEngineGlobalSettings.DnsMode) -> None: ...

        @staticmethod
        def __copy__() -> None: ...

    class SecureDnsMode(enum.Enum):

        SystemOnly               : QWebEngineGlobalSettings.SecureDnsMode = ... # 0x0
        SecureWithFallback       : QWebEngineGlobalSettings.SecureDnsMode = ... # 0x1
        SecureOnly               : QWebEngineGlobalSettings.SecureDnsMode = ... # 0x2


    @staticmethod
    def setDnsMode(dnsMode: PySide6.QtWebEngineCore.QWebEngineGlobalSettings.DnsMode) -> bool: ...


class DnsMode(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, DnsMode: PySide6.QtWebEngineCore.QWebEngineGlobalSettings.DnsMode) -> None: ...

    @staticmethod
    def __copy__() -> None: ...


class QWebEngineHistory(PySide6.QtCore.QObject):
    def __lshift__(self, stream: PySide6.QtCore.QDataStream) -> PySide6.QtCore.QDataStream: ...
    def __rshift__(self, stream: PySide6.QtCore.QDataStream) -> PySide6.QtCore.QDataStream: ...
    def back(self) -> None: ...
    def backItem(self) -> PySide6.QtWebEngineCore.QWebEngineHistoryItem: ...
    def backItems(self, maxItems: int) -> typing.List[PySide6.QtWebEngineCore.QWebEngineHistoryItem]: ...
    def backItemsModel(self) -> PySide6.QtWebEngineCore.QWebEngineHistoryModel: ...
    def canGoBack(self) -> bool: ...
    def canGoForward(self) -> bool: ...
    def clear(self) -> None: ...
    def count(self) -> int: ...
    def currentItem(self) -> PySide6.QtWebEngineCore.QWebEngineHistoryItem: ...
    def currentItemIndex(self) -> int: ...
    def forward(self) -> None: ...
    def forwardItem(self) -> PySide6.QtWebEngineCore.QWebEngineHistoryItem: ...
    def forwardItems(self, maxItems: int) -> typing.List[PySide6.QtWebEngineCore.QWebEngineHistoryItem]: ...
    def forwardItemsModel(self) -> PySide6.QtWebEngineCore.QWebEngineHistoryModel: ...
    def goToItem(self, item: PySide6.QtWebEngineCore.QWebEngineHistoryItem) -> None: ...
    def itemAt(self, i: int) -> PySide6.QtWebEngineCore.QWebEngineHistoryItem: ...
    def items(self) -> typing.List[PySide6.QtWebEngineCore.QWebEngineHistoryItem]: ...
    def itemsModel(self) -> PySide6.QtWebEngineCore.QWebEngineHistoryModel: ...


class QWebEngineHistoryItem(Shiboken.Object):

    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineHistoryItem) -> None: ...

    @staticmethod
    def __copy__() -> None: ...
    def iconUrl(self) -> PySide6.QtCore.QUrl: ...
    def isValid(self) -> bool: ...
    def lastVisited(self) -> PySide6.QtCore.QDateTime: ...
    def originalUrl(self) -> PySide6.QtCore.QUrl: ...
    def title(self) -> str: ...
    def url(self) -> PySide6.QtCore.QUrl: ...


class QWebEngineHistoryModel(PySide6.QtCore.QAbstractListModel):

    class Roles(enum.Enum):

        UrlRole                  : QWebEngineHistoryModel.Roles = ... # 0x100
        TitleRole                : QWebEngineHistoryModel.Roles = ... # 0x101
        OffsetRole               : QWebEngineHistoryModel.Roles = ... # 0x102
        IconUrlRole              : QWebEngineHistoryModel.Roles = ... # 0x103


    def data(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, role: int = ...) -> typing.Any: ...
    def reset(self) -> None: ...
    def roleNames(self) -> typing.Dict[int, PySide6.QtCore.QByteArray]: ...
    def rowCount(self, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex= ...) -> int: ...


class QWebEngineHttpRequest(Shiboken.Object):

    class Method(enum.Enum):

        Get                      : QWebEngineHttpRequest.Method = ... # 0x0
        Post                     : QWebEngineHttpRequest.Method = ... # 0x1


    @typing.overload
    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineHttpRequest) -> None: ...
    @typing.overload
    def __init__(self, url: PySide6.QtCore.QUrl | str= ..., method: PySide6.QtWebEngineCore.QWebEngineHttpRequest.Method = ...) -> None: ...

    def hasHeader(self, headerName: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview) -> bool: ...
    def header(self, headerName: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview) -> PySide6.QtCore.QByteArray: ...
    def headers(self) -> typing.List[PySide6.QtCore.QByteArray]: ...
    def method(self) -> PySide6.QtWebEngineCore.QWebEngineHttpRequest.Method: ...
    def postData(self) -> PySide6.QtCore.QByteArray: ...
    @staticmethod
    def postRequest(url: PySide6.QtCore.QUrl | str, postData: typing.Dict[str, str]) -> PySide6.QtWebEngineCore.QWebEngineHttpRequest: ...
    def setHeader(self, headerName: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, value: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview) -> None: ...
    def setMethod(self, method: PySide6.QtWebEngineCore.QWebEngineHttpRequest.Method) -> None: ...
    def setPostData(self, postData: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview) -> None: ...
    def setUrl(self, url: PySide6.QtCore.QUrl | str) -> None: ...
    def swap(self, other: PySide6.QtWebEngineCore.QWebEngineHttpRequest) -> None: ...
    def unsetHeader(self, headerName: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview) -> None: ...
    def url(self) -> PySide6.QtCore.QUrl: ...


class QWebEngineLoadingInfo(Shiboken.Object):

    class ErrorDomain(enum.Enum):

        NoErrorDomain            : QWebEngineLoadingInfo.ErrorDomain = ... # 0x0
        InternalErrorDomain      : QWebEngineLoadingInfo.ErrorDomain = ... # 0x1
        ConnectionErrorDomain    : QWebEngineLoadingInfo.ErrorDomain = ... # 0x2
        CertificateErrorDomain   : QWebEngineLoadingInfo.ErrorDomain = ... # 0x3
        HttpErrorDomain          : QWebEngineLoadingInfo.ErrorDomain = ... # 0x4
        FtpErrorDomain           : QWebEngineLoadingInfo.ErrorDomain = ... # 0x5
        DnsErrorDomain           : QWebEngineLoadingInfo.ErrorDomain = ... # 0x6
        HttpStatusCodeDomain     : QWebEngineLoadingInfo.ErrorDomain = ... # 0x7

    class LoadStatus(enum.Enum):

        LoadStartedStatus        : QWebEngineLoadingInfo.LoadStatus = ... # 0x0
        LoadStoppedStatus        : QWebEngineLoadingInfo.LoadStatus = ... # 0x1
        LoadSucceededStatus      : QWebEngineLoadingInfo.LoadStatus = ... # 0x2
        LoadFailedStatus         : QWebEngineLoadingInfo.LoadStatus = ... # 0x3


    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineLoadingInfo) -> None: ...

    @staticmethod
    def __copy__() -> None: ...
    def errorCode(self) -> int: ...
    def errorDomain(self) -> PySide6.QtWebEngineCore.QWebEngineLoadingInfo.ErrorDomain: ...
    def errorString(self) -> str: ...
    def isErrorPage(self) -> bool: ...
    def responseHeaders(self) -> typing.Dict[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]: ...
    def status(self) -> PySide6.QtWebEngineCore.QWebEngineLoadingInfo.LoadStatus: ...
    def url(self) -> PySide6.QtCore.QUrl: ...


class QWebEngineNavigationRequest(PySide6.QtCore.QObject):

    actionChanged            : typing.ClassVar[Signal] = ... # actionChanged()

    class NavigationRequestAction(enum.Enum):

        AcceptRequest            : QWebEngineNavigationRequest.NavigationRequestAction = ... # 0x0
        IgnoreRequest            : QWebEngineNavigationRequest.NavigationRequestAction = ... # 0xff

    class NavigationType(enum.Enum):

        LinkClickedNavigation    : QWebEngineNavigationRequest.NavigationType = ... # 0x0
        TypedNavigation          : QWebEngineNavigationRequest.NavigationType = ... # 0x1
        FormSubmittedNavigation  : QWebEngineNavigationRequest.NavigationType = ... # 0x2
        BackForwardNavigation    : QWebEngineNavigationRequest.NavigationType = ... # 0x3
        ReloadNavigation         : QWebEngineNavigationRequest.NavigationType = ... # 0x4
        OtherNavigation          : QWebEngineNavigationRequest.NavigationType = ... # 0x5
        RedirectNavigation       : QWebEngineNavigationRequest.NavigationType = ... # 0x6


    def accept(self) -> None: ...
    def hasFormData(self) -> bool: ...
    def isMainFrame(self) -> bool: ...
    def navigationType(self) -> PySide6.QtWebEngineCore.QWebEngineNavigationRequest.NavigationType: ...
    def reject(self) -> None: ...
    def url(self) -> PySide6.QtCore.QUrl: ...


class QWebEngineNewWindowRequest(PySide6.QtCore.QObject):

    class DestinationType(enum.Enum):

        InNewWindow              : QWebEngineNewWindowRequest.DestinationType = ... # 0x0
        InNewTab                 : QWebEngineNewWindowRequest.DestinationType = ... # 0x1
        InNewDialog              : QWebEngineNewWindowRequest.DestinationType = ... # 0x2
        InNewBackgroundTab       : QWebEngineNewWindowRequest.DestinationType = ... # 0x3


    def destination(self) -> PySide6.QtWebEngineCore.QWebEngineNewWindowRequest.DestinationType: ...
    def isUserInitiated(self) -> bool: ...
    def openIn(self, arg__1: PySide6.QtWebEngineCore.QWebEnginePage) -> None: ...
    def requestedGeometry(self) -> PySide6.QtCore.QRect: ...
    def requestedUrl(self) -> PySide6.QtCore.QUrl: ...


class QWebEngineNotification(PySide6.QtCore.QObject):

    closed                   : typing.ClassVar[Signal] = ... # closed()
    def click(self) -> None: ...
    def close(self) -> None: ...
    def direction(self) -> PySide6.QtCore.Qt.LayoutDirection: ...
    def icon(self) -> PySide6.QtGui.QImage: ...
    def language(self) -> str: ...
    def matches(self, other: PySide6.QtWebEngineCore.QWebEngineNotification) -> bool: ...
    def message(self) -> str: ...
    def origin(self) -> PySide6.QtCore.QUrl: ...
    def show(self) -> None: ...
    def tag(self) -> str: ...
    def title(self) -> str: ...


class QWebEnginePage(PySide6.QtCore.QObject):

    _q_aboutToDelete         : typing.ClassVar[Signal] = ... # _q_aboutToDelete()
    audioMutedChanged        : typing.ClassVar[Signal] = ... # audioMutedChanged(bool)
    authenticationRequired   : typing.ClassVar[Signal] = ... # authenticationRequired(QUrl,QAuthenticator*)
    certificateError         : typing.ClassVar[Signal] = ... # certificateError(QWebEngineCertificateError)
    contentsSizeChanged      : typing.ClassVar[Signal] = ... # contentsSizeChanged(QSizeF)
    desktopMediaRequested    : typing.ClassVar[Signal] = ... # desktopMediaRequested(QWebEngineDesktopMediaRequest)
    featurePermissionRequestCanceled: typing.ClassVar[Signal] = ... # featurePermissionRequestCanceled(QUrl,QWebEnginePage::Feature)
    featurePermissionRequested: typing.ClassVar[Signal] = ... # featurePermissionRequested(QUrl,QWebEnginePage::Feature)
    fileSystemAccessRequested: typing.ClassVar[Signal] = ... # fileSystemAccessRequested(QWebEngineFileSystemAccessRequest)
    findTextFinished         : typing.ClassVar[Signal] = ... # findTextFinished(QWebEngineFindTextResult)
    fullScreenRequested      : typing.ClassVar[Signal] = ... # fullScreenRequested(QWebEngineFullScreenRequest)
    geometryChangeRequested  : typing.ClassVar[Signal] = ... # geometryChangeRequested(QRect)
    iconChanged              : typing.ClassVar[Signal] = ... # iconChanged(QIcon)
    iconUrlChanged           : typing.ClassVar[Signal] = ... # iconUrlChanged(QUrl)
    lifecycleStateChanged    : typing.ClassVar[Signal] = ... # lifecycleStateChanged(LifecycleState)
    linkHovered              : typing.ClassVar[Signal] = ... # linkHovered(QString)
    loadFinished             : typing.ClassVar[Signal] = ... # loadFinished(bool)
    loadProgress             : typing.ClassVar[Signal] = ... # loadProgress(int)
    loadStarted              : typing.ClassVar[Signal] = ... # loadStarted()
    loadingChanged           : typing.ClassVar[Signal] = ... # loadingChanged(QWebEngineLoadingInfo)
    navigationRequested      : typing.ClassVar[Signal] = ... # navigationRequested(QWebEngineNavigationRequest&)
    newWindowRequested       : typing.ClassVar[Signal] = ... # newWindowRequested(QWebEngineNewWindowRequest&)
    pdfPrintingFinished      : typing.ClassVar[Signal] = ... # pdfPrintingFinished(QString,bool)
    permissionRequested      : typing.ClassVar[Signal] = ... # permissionRequested(QWebEnginePermission)
    printRequested           : typing.ClassVar[Signal] = ... # printRequested()
    printRequestedByFrame    : typing.ClassVar[Signal] = ... # printRequestedByFrame(QWebEngineFrame)
    proxyAuthenticationRequired: typing.ClassVar[Signal] = ... # proxyAuthenticationRequired(QUrl,QAuthenticator*,QString)
    quotaRequested           : typing.ClassVar[Signal] = ... # quotaRequested(QWebEngineQuotaRequest)
    recentlyAudibleChanged   : typing.ClassVar[Signal] = ... # recentlyAudibleChanged(bool)
    recommendedStateChanged  : typing.ClassVar[Signal] = ... # recommendedStateChanged(LifecycleState)
    registerProtocolHandlerRequested: typing.ClassVar[Signal] = ... # registerProtocolHandlerRequested(QWebEngineRegisterProtocolHandlerRequest)
    renderProcessPidChanged  : typing.ClassVar[Signal] = ... # renderProcessPidChanged(qlonglong)
    renderProcessTerminated  : typing.ClassVar[Signal] = ... # renderProcessTerminated(RenderProcessTerminationStatus,int)
    scrollPositionChanged    : typing.ClassVar[Signal] = ... # scrollPositionChanged(QPointF)
    selectClientCertificate  : typing.ClassVar[Signal] = ... # selectClientCertificate(QWebEngineClientCertificateSelection)
    selectionChanged         : typing.ClassVar[Signal] = ... # selectionChanged()
    titleChanged             : typing.ClassVar[Signal] = ... # titleChanged(QString)
    urlChanged               : typing.ClassVar[Signal] = ... # urlChanged(QUrl)
    visibleChanged           : typing.ClassVar[Signal] = ... # visibleChanged(bool)
    webAuthUxRequested       : typing.ClassVar[Signal] = ... # webAuthUxRequested(QWebEngineWebAuthUxRequest*)
    windowCloseRequested     : typing.ClassVar[Signal] = ... # windowCloseRequested()
    zoomFactorChanged        : typing.ClassVar[Signal] = ... # zoomFactorChanged(double)

    class Feature(enum.Enum):

        Notifications            : QWebEnginePage.Feature = ... # 0x0
        Geolocation              : QWebEnginePage.Feature = ... # 0x1
        MediaAudioCapture        : QWebEnginePage.Feature = ... # 0x2
        MediaVideoCapture        : QWebEnginePage.Feature = ... # 0x3
        MediaAudioVideoCapture   : QWebEnginePage.Feature = ... # 0x4
        MouseLock                : QWebEnginePage.Feature = ... # 0x5
        DesktopVideoCapture      : QWebEnginePage.Feature = ... # 0x6
        DesktopAudioVideoCapture : QWebEnginePage.Feature = ... # 0x7
        ClipboardReadWrite       : QWebEnginePage.Feature = ... # 0x8
        LocalFontsAccess         : QWebEnginePage.Feature = ... # 0x9

    class FileSelectionMode(enum.Enum):

        FileSelectOpen           : QWebEnginePage.FileSelectionMode = ... # 0x0
        FileSelectOpenMultiple   : QWebEnginePage.FileSelectionMode = ... # 0x1
        FileSelectUploadFolder   : QWebEnginePage.FileSelectionMode = ... # 0x2
        FileSelectSave           : QWebEnginePage.FileSelectionMode = ... # 0x3

    class FindFlag(enum.Flag):

        FindBackward             : QWebEnginePage.FindFlag = ... # 0x1
        FindCaseSensitively      : QWebEnginePage.FindFlag = ... # 0x2

    class JavaScriptConsoleMessageLevel(enum.Enum):

        InfoMessageLevel         : QWebEnginePage.JavaScriptConsoleMessageLevel = ... # 0x0
        WarningMessageLevel      : QWebEnginePage.JavaScriptConsoleMessageLevel = ... # 0x1
        ErrorMessageLevel        : QWebEnginePage.JavaScriptConsoleMessageLevel = ... # 0x2

    class LifecycleState(enum.Enum):

        Active                   : QWebEnginePage.LifecycleState = ... # 0x0
        Frozen                   : QWebEnginePage.LifecycleState = ... # 0x1
        Discarded                : QWebEnginePage.LifecycleState = ... # 0x2

    class NavigationType(enum.Enum):

        NavigationTypeLinkClicked: QWebEnginePage.NavigationType = ... # 0x0
        NavigationTypeTyped      : QWebEnginePage.NavigationType = ... # 0x1
        NavigationTypeFormSubmitted: QWebEnginePage.NavigationType = ... # 0x2
        NavigationTypeBackForward: QWebEnginePage.NavigationType = ... # 0x3
        NavigationTypeReload     : QWebEnginePage.NavigationType = ... # 0x4
        NavigationTypeOther      : QWebEnginePage.NavigationType = ... # 0x5
        NavigationTypeRedirect   : QWebEnginePage.NavigationType = ... # 0x6

    class PermissionPolicy(enum.Enum):

        PermissionUnknown        : QWebEnginePage.PermissionPolicy = ... # 0x0
        PermissionGrantedByUser  : QWebEnginePage.PermissionPolicy = ... # 0x1
        PermissionDeniedByUser   : QWebEnginePage.PermissionPolicy = ... # 0x2

    class RenderProcessTerminationStatus(enum.Enum):

        NormalTerminationStatus  : QWebEnginePage.RenderProcessTerminationStatus = ... # 0x0
        AbnormalTerminationStatus: QWebEnginePage.RenderProcessTerminationStatus = ... # 0x1
        CrashedTerminationStatus : QWebEnginePage.RenderProcessTerminationStatus = ... # 0x2
        KilledTerminationStatus  : QWebEnginePage.RenderProcessTerminationStatus = ... # 0x3

    class WebAction(enum.Enum):

        NoWebAction              : QWebEnginePage.WebAction = ... # -0x1
        Back                     : QWebEnginePage.WebAction = ... # 0x0
        Forward                  : QWebEnginePage.WebAction = ... # 0x1
        Stop                     : QWebEnginePage.WebAction = ... # 0x2
        Reload                   : QWebEnginePage.WebAction = ... # 0x3
        Cut                      : QWebEnginePage.WebAction = ... # 0x4
        Copy                     : QWebEnginePage.WebAction = ... # 0x5
        Paste                    : QWebEnginePage.WebAction = ... # 0x6
        Undo                     : QWebEnginePage.WebAction = ... # 0x7
        Redo                     : QWebEnginePage.WebAction = ... # 0x8
        SelectAll                : QWebEnginePage.WebAction = ... # 0x9
        ReloadAndBypassCache     : QWebEnginePage.WebAction = ... # 0xa
        PasteAndMatchStyle       : QWebEnginePage.WebAction = ... # 0xb
        OpenLinkInThisWindow     : QWebEnginePage.WebAction = ... # 0xc
        OpenLinkInNewWindow      : QWebEnginePage.WebAction = ... # 0xd
        OpenLinkInNewTab         : QWebEnginePage.WebAction = ... # 0xe
        CopyLinkToClipboard      : QWebEnginePage.WebAction = ... # 0xf
        DownloadLinkToDisk       : QWebEnginePage.WebAction = ... # 0x10
        CopyImageToClipboard     : QWebEnginePage.WebAction = ... # 0x11
        CopyImageUrlToClipboard  : QWebEnginePage.WebAction = ... # 0x12
        DownloadImageToDisk      : QWebEnginePage.WebAction = ... # 0x13
        CopyMediaUrlToClipboard  : QWebEnginePage.WebAction = ... # 0x14
        ToggleMediaControls      : QWebEnginePage.WebAction = ... # 0x15
        ToggleMediaLoop          : QWebEnginePage.WebAction = ... # 0x16
        ToggleMediaPlayPause     : QWebEnginePage.WebAction = ... # 0x17
        ToggleMediaMute          : QWebEnginePage.WebAction = ... # 0x18
        DownloadMediaToDisk      : QWebEnginePage.WebAction = ... # 0x19
        InspectElement           : QWebEnginePage.WebAction = ... # 0x1a
        ExitFullScreen           : QWebEnginePage.WebAction = ... # 0x1b
        RequestClose             : QWebEnginePage.WebAction = ... # 0x1c
        Unselect                 : QWebEnginePage.WebAction = ... # 0x1d
        SavePage                 : QWebEnginePage.WebAction = ... # 0x1e
        OpenLinkInNewBackgroundTab: QWebEnginePage.WebAction = ... # 0x1f
        ViewSource               : QWebEnginePage.WebAction = ... # 0x20
        ToggleBold               : QWebEnginePage.WebAction = ... # 0x21
        ToggleItalic             : QWebEnginePage.WebAction = ... # 0x22
        ToggleUnderline          : QWebEnginePage.WebAction = ... # 0x23
        ToggleStrikethrough      : QWebEnginePage.WebAction = ... # 0x24
        AlignLeft                : QWebEnginePage.WebAction = ... # 0x25
        AlignCenter              : QWebEnginePage.WebAction = ... # 0x26
        AlignRight               : QWebEnginePage.WebAction = ... # 0x27
        AlignJustified           : QWebEnginePage.WebAction = ... # 0x28
        Indent                   : QWebEnginePage.WebAction = ... # 0x29
        Outdent                  : QWebEnginePage.WebAction = ... # 0x2a
        InsertOrderedList        : QWebEnginePage.WebAction = ... # 0x2b
        InsertUnorderedList      : QWebEnginePage.WebAction = ... # 0x2c
        ChangeTextDirectionLTR   : QWebEnginePage.WebAction = ... # 0x2d
        ChangeTextDirectionRTL   : QWebEnginePage.WebAction = ... # 0x2e
        WebActionCount           : QWebEnginePage.WebAction = ... # 0x2f

    class WebWindowType(enum.Enum):

        WebBrowserWindow         : QWebEnginePage.WebWindowType = ... # 0x0
        WebBrowserTab            : QWebEnginePage.WebWindowType = ... # 0x1
        WebDialog                : QWebEnginePage.WebWindowType = ... # 0x2
        WebBrowserBackgroundTab  : QWebEnginePage.WebWindowType = ... # 0x3


    @typing.overload
    def __init__(self, parent: PySide6.QtCore.QObject | None= ...) -> None: ...
    @typing.overload
    def __init__(self, profile: PySide6.QtWebEngineCore.QWebEngineProfile, parent: PySide6.QtCore.QObject | None= ...) -> None: ...

    def acceptAsNewWindow(self, request: PySide6.QtWebEngineCore.QWebEngineNewWindowRequest) -> None: ...
    def acceptNavigationRequest(self, url: PySide6.QtCore.QUrl | str, type: PySide6.QtWebEngineCore.QWebEnginePage.NavigationType, isMainFrame: bool) -> bool: ...
    def action(self, action: PySide6.QtWebEngineCore.QWebEnginePage.WebAction) -> PySide6.QtGui.QAction: ...
    def backgroundColor(self) -> PySide6.QtGui.QColor: ...
    def chooseFiles(self, mode: PySide6.QtWebEngineCore.QWebEnginePage.FileSelectionMode, oldFiles: typing.Sequence[str], acceptedMimeTypes: typing.Sequence[str]) -> typing.List[str]: ...
    def contentsSize(self) -> PySide6.QtCore.QSizeF: ...
    def createWindow(self, type: PySide6.QtWebEngineCore.QWebEnginePage.WebWindowType) -> PySide6.QtWebEngineCore.QWebEnginePage: ...
    def devToolsId(self) -> str: ...
    def devToolsPage(self) -> PySide6.QtWebEngineCore.QWebEnginePage: ...
    def download(self, url: PySide6.QtCore.QUrl | str, filename: str = ...) -> None: ...
    def event(self, arg__1: PySide6.QtCore.QEvent) -> bool: ...
    @typing.overload
    def findText(self, arg__1: str, arg__2: PySide6.QtWebEngineCore.QWebEnginePage.FindFlag, arg__3: object) -> None: ...
    @typing.overload
    def findText(self, subString: str, options: PySide6.QtWebEngineCore.QWebEnginePage.FindFlag = ...) -> None: ...
    def hasSelection(self) -> bool: ...
    def history(self) -> PySide6.QtWebEngineCore.QWebEngineHistory: ...
    def icon(self) -> PySide6.QtGui.QIcon: ...
    def iconUrl(self) -> PySide6.QtCore.QUrl: ...
    def inspectedPage(self) -> PySide6.QtWebEngineCore.QWebEnginePage: ...
    def isAudioMuted(self) -> bool: ...
    def isLoading(self) -> bool: ...
    def isVisible(self) -> bool: ...
    def javaScriptAlert(self, securityOrigin: PySide6.QtCore.QUrl | str, msg: str) -> None: ...
    def javaScriptConfirm(self, securityOrigin: PySide6.QtCore.QUrl | str, msg: str) -> bool: ...
    def javaScriptConsoleMessage(self, level: PySide6.QtWebEngineCore.QWebEnginePage.JavaScriptConsoleMessageLevel, message: str, lineNumber: int, sourceID: str) -> None: ...
    def javaScriptPrompt(self, securityOrigin: PySide6.QtCore.QUrl | str, msg: str, defaultValue: str) -> typing.Tuple[bool, str]: ...
    def lifecycleState(self) -> PySide6.QtWebEngineCore.QWebEnginePage.LifecycleState: ...
    @typing.overload
    def load(self, request: PySide6.QtWebEngineCore.QWebEngineHttpRequest) -> None: ...
    @typing.overload
    def load(self, url: PySide6.QtCore.QUrl | str) -> None: ...
    def printToPdf(self, filePath: str, layout: PySide6.QtGui.QPageLayout = ..., ranges: PySide6.QtGui.QPageRanges = ...) -> None: ...
    def profile(self) -> PySide6.QtWebEngineCore.QWebEngineProfile: ...
    def recentlyAudible(self) -> bool: ...
    def recommendedState(self) -> PySide6.QtWebEngineCore.QWebEnginePage.LifecycleState: ...
    def renderProcessPid(self) -> int: ...
    def replaceMisspelledWord(self, replacement: str) -> None: ...
    def requestedUrl(self) -> PySide6.QtCore.QUrl: ...
    @typing.overload
    def runJavaScript(self, arg__1: str, arg__2: int, arg__3: object) -> None: ...
    @typing.overload
    def runJavaScript(self, scriptSource: str, worldId: int = ...) -> None: ...
    def save(self, filePath: str, format: PySide6.QtWebEngineCore.QWebEngineDownloadRequest.SavePageFormat = ...) -> None: ...
    def scripts(self) -> PySide6.QtWebEngineCore.QWebEngineScriptCollection: ...
    def scrollPosition(self) -> PySide6.QtCore.QPointF: ...
    def selectedText(self) -> str: ...
    def setAudioMuted(self, muted: bool) -> None: ...
    def setBackgroundColor(self, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int) -> None: ...
    def setContent(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, mimeType: str = ..., baseUrl: PySide6.QtCore.QUrl | str= ...) -> None: ...
    def setDevToolsPage(self, page: PySide6.QtWebEngineCore.QWebEnginePage) -> None: ...
    def setFeaturePermission(self, securityOrigin: PySide6.QtCore.QUrl | str, feature: PySide6.QtWebEngineCore.QWebEnginePage.Feature, policy: PySide6.QtWebEngineCore.QWebEnginePage.PermissionPolicy) -> None: ...
    def setHtml(self, html: str, baseUrl: PySide6.QtCore.QUrl | str= ...) -> None: ...
    def setInspectedPage(self, page: PySide6.QtWebEngineCore.QWebEnginePage) -> None: ...
    def setLifecycleState(self, state: PySide6.QtWebEngineCore.QWebEnginePage.LifecycleState) -> None: ...
    def setUrl(self, url: PySide6.QtCore.QUrl | str) -> None: ...
    def setUrlRequestInterceptor(self, interceptor: PySide6.QtWebEngineCore.QWebEngineUrlRequestInterceptor) -> None: ...
    def setVisible(self, visible: bool) -> None: ...
    def setWebChannel(self, arg__1: PySide6.QtWebChannel.QWebChannel, worldId: int = ...) -> None: ...
    def setZoomFactor(self, factor: float) -> None: ...
    def settings(self) -> PySide6.QtWebEngineCore.QWebEngineSettings: ...
    def title(self) -> str: ...
    def toHtml(self, arg__1: object) -> None: ...
    def toPlainText(self, arg__1: object) -> None: ...
    def triggerAction(self, action: PySide6.QtWebEngineCore.QWebEnginePage.WebAction, checked: bool = ...) -> None: ...
    def url(self) -> PySide6.QtCore.QUrl: ...
    def webChannel(self) -> PySide6.QtWebChannel.QWebChannel: ...
    def zoomFactor(self) -> float: ...


class QWebEngineProfile(PySide6.QtCore.QObject):

    clearHttpCacheCompleted  : typing.ClassVar[Signal] = ... # clearHttpCacheCompleted()
    downloadRequested        : typing.ClassVar[Signal] = ... # downloadRequested(QWebEngineDownloadRequest*)

    class HttpCacheType(enum.Enum):

        MemoryHttpCache          : QWebEngineProfile.HttpCacheType = ... # 0x0
        DiskHttpCache            : QWebEngineProfile.HttpCacheType = ... # 0x1
        NoCache                  : QWebEngineProfile.HttpCacheType = ... # 0x2

    class PersistentCookiesPolicy(enum.Enum):

        NoPersistentCookies      : QWebEngineProfile.PersistentCookiesPolicy = ... # 0x0
        AllowPersistentCookies   : QWebEngineProfile.PersistentCookiesPolicy = ... # 0x1
        ForcePersistentCookies   : QWebEngineProfile.PersistentCookiesPolicy = ... # 0x2

    class PersistentPermissionsPolicy(enum.Enum):

        AskEveryTime             : QWebEngineProfile.PersistentPermissionsPolicy = ... # 0x0
        StoreInMemory            : QWebEngineProfile.PersistentPermissionsPolicy = ... # 0x1
        StoreOnDisk              : QWebEngineProfile.PersistentPermissionsPolicy = ... # 0x2


    @typing.overload
    def __init__(self, name: str, parent: PySide6.QtCore.QObject | None= ...) -> None: ...
    @typing.overload
    def __init__(self, parent: PySide6.QtCore.QObject | None= ...) -> None: ...

    def cachePath(self) -> str: ...
    def clearAllVisitedLinks(self) -> None: ...
    def clearHttpCache(self) -> None: ...
    def clearVisitedLinks(self, urls: typing.Sequence[PySide6.QtCore.QUrl]) -> None: ...
    def clientCertificateStore(self) -> PySide6.QtWebEngineCore.QWebEngineClientCertificateStore: ...
    def clientHints(self) -> PySide6.QtWebEngineCore.QWebEngineClientHints: ...
    def cookieStore(self) -> PySide6.QtWebEngineCore.QWebEngineCookieStore: ...
    @staticmethod
    def defaultProfile() -> PySide6.QtWebEngineCore.QWebEngineProfile: ...
    def downloadPath(self) -> str: ...
    def httpAcceptLanguage(self) -> str: ...
    def httpCacheMaximumSize(self) -> int: ...
    def httpCacheType(self) -> PySide6.QtWebEngineCore.QWebEngineProfile.HttpCacheType: ...
    def httpUserAgent(self) -> str: ...
    def installUrlSchemeHandler(self, scheme: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, arg__2: PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler) -> None: ...
    def isOffTheRecord(self) -> bool: ...
    def isPushServiceEnabled(self) -> bool: ...
    def isSpellCheckEnabled(self) -> bool: ...
    def persistentCookiesPolicy(self) -> PySide6.QtWebEngineCore.QWebEngineProfile.PersistentCookiesPolicy: ...
    def persistentPermissionsPolicy(self) -> PySide6.QtWebEngineCore.QWebEngineProfile.PersistentPermissionsPolicy: ...
    def persistentStoragePath(self) -> str: ...
    def removeAllUrlSchemeHandlers(self) -> None: ...
    def removeUrlScheme(self, scheme: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview) -> None: ...
    def removeUrlSchemeHandler(self, arg__1: PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler) -> None: ...
    def scripts(self) -> PySide6.QtWebEngineCore.QWebEngineScriptCollection: ...
    def setCachePath(self, path: str) -> None: ...
    def setDownloadPath(self, path: str) -> None: ...
    def setHttpAcceptLanguage(self, httpAcceptLanguage: str) -> None: ...
    def setHttpCacheMaximumSize(self, maxSize: int) -> None: ...
    def setHttpCacheType(self, arg__1: PySide6.QtWebEngineCore.QWebEngineProfile.HttpCacheType) -> None: ...
    def setHttpUserAgent(self, userAgent: str) -> None: ...
    def setNotificationPresenter(self, notificationPresenter: typing.Callable) -> None: ...
    def setPersistentCookiesPolicy(self, arg__1: PySide6.QtWebEngineCore.QWebEngineProfile.PersistentCookiesPolicy) -> None: ...
    def setPersistentPermissionsPolicy(self, arg__1: PySide6.QtWebEngineCore.QWebEngineProfile.PersistentPermissionsPolicy) -> None: ...
    def setPersistentStoragePath(self, path: str) -> None: ...
    def setPushServiceEnabled(self, enabled: bool) -> None: ...
    def setSpellCheckEnabled(self, enabled: bool) -> None: ...
    def setSpellCheckLanguages(self, languages: typing.Sequence[str]) -> None: ...
    def setUrlRequestInterceptor(self, interceptor: PySide6.QtWebEngineCore.QWebEngineUrlRequestInterceptor) -> None: ...
    def settings(self) -> PySide6.QtWebEngineCore.QWebEngineSettings: ...
    def spellCheckLanguages(self) -> typing.List[str]: ...
    def storageName(self) -> str: ...
    def urlSchemeHandler(self, arg__1: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview) -> PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler: ...
    def visitedLinksContainsUrl(self, url: PySide6.QtCore.QUrl | str) -> bool: ...


class QWebEngineQuotaRequest(Shiboken.Object):

    def __init__(self) -> None: ...

    def accept(self) -> None: ...
    def origin(self) -> PySide6.QtCore.QUrl: ...
    def reject(self) -> None: ...
    def requestedSize(self) -> int: ...


class QWebEngineRegisterProtocolHandlerRequest(Shiboken.Object):

    def __init__(self) -> None: ...

    @staticmethod
    def __copy__() -> None: ...
    def accept(self) -> None: ...
    def origin(self) -> PySide6.QtCore.QUrl: ...
    def reject(self) -> None: ...
    def scheme(self) -> str: ...


class QWebEngineScript(Shiboken.Object):

    class InjectionPoint(enum.Enum):

        Deferred                 : QWebEngineScript.InjectionPoint = ... # 0x0
        DocumentReady            : QWebEngineScript.InjectionPoint = ... # 0x1
        DocumentCreation         : QWebEngineScript.InjectionPoint = ... # 0x2

    class ScriptWorldId(enum.IntEnum):

        MainWorld                : QWebEngineScript.ScriptWorldId = ... # 0x0
        ApplicationWorld         : QWebEngineScript.ScriptWorldId = ... # 0x1
        UserWorld                : QWebEngineScript.ScriptWorldId = ... # 0x2


    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtWebEngineCore.QWebEngineScript) -> None: ...

    @staticmethod
    def __copy__() -> None: ...
    def injectionPoint(self) -> PySide6.QtWebEngineCore.QWebEngineScript.InjectionPoint: ...
    def name(self) -> str: ...
    def runsOnSubFrames(self) -> bool: ...
    def setInjectionPoint(self, arg__1: PySide6.QtWebEngineCore.QWebEngineScript.InjectionPoint) -> None: ...
    def setName(self, arg__1: str) -> None: ...
    def setRunsOnSubFrames(self, on: bool) -> None: ...
    def setSourceCode(self, arg__1: str) -> None: ...
    def setSourceUrl(self, url: PySide6.QtCore.QUrl | str) -> None: ...
    def setWorldId(self, arg__1: int) -> None: ...
    def sourceCode(self) -> str: ...
    def sourceUrl(self) -> PySide6.QtCore.QUrl: ...
    def swap(self, other: PySide6.QtWebEngineCore.QWebEngineScript) -> None: ...
    def worldId(self) -> int: ...


class QWebEngineScriptCollection(Shiboken.Object):
    def clear(self) -> None: ...
    def contains(self, value: PySide6.QtWebEngineCore.QWebEngineScript) -> bool: ...
    def count(self) -> int: ...
    def find(self, name: str) -> typing.List[PySide6.QtWebEngineCore.QWebEngineScript]: ...
    @typing.overload
    def insert(self, arg__1: PySide6.QtWebEngineCore.QWebEngineScript) -> None: ...
    @typing.overload
    def insert(self, list: typing.Sequence[PySide6.QtWebEngineCore.QWebEngineScript]) -> None: ...
    def isEmpty(self) -> bool: ...
    def remove(self, arg__1: PySide6.QtWebEngineCore.QWebEngineScript) -> bool: ...
    def toList(self) -> typing.List[PySide6.QtWebEngineCore.QWebEngineScript]: ...


class QWebEngineSettings(Shiboken.Object):

    class FontFamily(enum.Enum):

        StandardFont             : QWebEngineSettings.FontFamily = ... # 0x0
        FixedFont                : QWebEngineSettings.FontFamily = ... # 0x1
        SerifFont                : QWebEngineSettings.FontFamily = ... # 0x2
        SansSerifFont            : QWebEngineSettings.FontFamily = ... # 0x3
        CursiveFont              : QWebEngineSettings.FontFamily = ... # 0x4
        FantasyFont              : QWebEngineSettings.FontFamily = ... # 0x5
        PictographFont           : QWebEngineSettings.FontFamily = ... # 0x6

    class FontSize(enum.Enum):

        MinimumFontSize          : QWebEngineSettings.FontSize = ... # 0x0
        MinimumLogicalFontSize   : QWebEngineSettings.FontSize = ... # 0x1
        DefaultFontSize          : QWebEngineSettings.FontSize = ... # 0x2
        DefaultFixedFontSize     : QWebEngineSettings.FontSize = ... # 0x3

    class ImageAnimationPolicy(enum.Enum):

        Inherited                : QWebEngineSettings.ImageAnimationPolicy = ... # 0x0
        Allow                    : QWebEngineSettings.ImageAnimationPolicy = ... # 0x1
        AnimateOnce              : QWebEngineSettings.ImageAnimationPolicy = ... # 0x2
        Disallow                 : QWebEngineSettings.ImageAnimationPolicy = ... # 0x3

    class UnknownUrlSchemePolicy(enum.Enum):

        InheritedUnknownUrlSchemePolicy: QWebEngineSettings.UnknownUrlSchemePolicy = ... # 0x0
        DisallowUnknownUrlSchemes: QWebEngineSettings.UnknownUrlSchemePolicy = ... # 0x1
        AllowUnknownUrlSchemesFromUserInteraction: QWebEngineSettings.UnknownUrlSchemePolicy = ... # 0x2
        AllowAllUnknownUrlSchemes: QWebEngineSettings.UnknownUrlSchemePolicy = ... # 0x3

    class WebAttribute(enum.Enum):

        AutoLoadImages           : QWebEngineSettings.WebAttribute = ... # 0x0
        JavascriptEnabled        : QWebEngineSettings.WebAttribute = ... # 0x1
        JavascriptCanOpenWindows : QWebEngineSettings.WebAttribute = ... # 0x2
        JavascriptCanAccessClipboard: QWebEngineSettings.WebAttribute = ... # 0x3
        LinksIncludedInFocusChain: QWebEngineSettings.WebAttribute = ... # 0x4
        LocalStorageEnabled      : QWebEngineSettings.WebAttribute = ... # 0x5
        LocalContentCanAccessRemoteUrls: QWebEngineSettings.WebAttribute = ... # 0x6
        XSSAuditingEnabled       : QWebEngineSettings.WebAttribute = ... # 0x7
        SpatialNavigationEnabled : QWebEngineSettings.WebAttribute = ... # 0x8
        LocalContentCanAccessFileUrls: QWebEngineSettings.WebAttribute = ... # 0x9
        HyperlinkAuditingEnabled : QWebEngineSettings.WebAttribute = ... # 0xa
        ScrollAnimatorEnabled    : QWebEngineSettings.WebAttribute = ... # 0xb
        ErrorPageEnabled         : QWebEngineSettings.WebAttribute = ... # 0xc
        PluginsEnabled           : QWebEngineSettings.WebAttribute = ... # 0xd
        FullScreenSupportEnabled : QWebEngineSettings.WebAttribute = ... # 0xe
        ScreenCaptureEnabled     : QWebEngineSettings.WebAttribute = ... # 0xf
        WebGLEnabled             : QWebEngineSettings.WebAttribute = ... # 0x10
        Accelerated2dCanvasEnabled: QWebEngineSettings.WebAttribute = ... # 0x11
        AutoLoadIconsForPage     : QWebEngineSettings.WebAttribute = ... # 0x12
        TouchIconsEnabled        : QWebEngineSettings.WebAttribute = ... # 0x13
        FocusOnNavigationEnabled : QWebEngineSettings.WebAttribute = ... # 0x14
        PrintElementBackgrounds  : QWebEngineSettings.WebAttribute = ... # 0x15
        AllowRunningInsecureContent: QWebEngineSettings.WebAttribute = ... # 0x16
        AllowGeolocationOnInsecureOrigins: QWebEngineSettings.WebAttribute = ... # 0x17
        AllowWindowActivationFromJavaScript: QWebEngineSettings.WebAttribute = ... # 0x18
        ShowScrollBars           : QWebEngineSettings.WebAttribute = ... # 0x19
        PlaybackRequiresUserGesture: QWebEngineSettings.WebAttribute = ... # 0x1a
        WebRTCPublicInterfacesOnly: QWebEngineSettings.WebAttribute = ... # 0x1b
        JavascriptCanPaste       : QWebEngineSettings.WebAttribute = ... # 0x1c
        DnsPrefetchEnabled       : QWebEngineSettings.WebAttribute = ... # 0x1d
        PdfViewerEnabled         : QWebEngineSettings.WebAttribute = ... # 0x1e
        NavigateOnDropEnabled    : QWebEngineSettings.WebAttribute = ... # 0x1f
        ReadingFromCanvasEnabled : QWebEngineSettings.WebAttribute = ... # 0x20
        ForceDarkMode            : QWebEngineSettings.WebAttribute = ... # 0x21


    def defaultTextEncoding(self) -> str: ...
    def fontFamily(self, which: PySide6.QtWebEngineCore.QWebEngineSettings.FontFamily) -> str: ...
    def fontSize(self, type: PySide6.QtWebEngineCore.QWebEngineSettings.FontSize) -> int: ...
    def imageAnimationPolicy(self) -> PySide6.QtWebEngineCore.QWebEngineSettings.ImageAnimationPolicy: ...
    def resetAttribute(self, attr: PySide6.QtWebEngineCore.QWebEngineSettings.WebAttribute) -> None: ...
    def resetFontFamily(self, which: PySide6.QtWebEngineCore.QWebEngineSettings.FontFamily) -> None: ...
    def resetFontSize(self, type: PySide6.QtWebEngineCore.QWebEngineSettings.FontSize) -> None: ...
    def resetImageAnimationPolicy(self) -> None: ...
    def resetUnknownUrlSchemePolicy(self) -> None: ...
    def setAttribute(self, attr: PySide6.QtWebEngineCore.QWebEngineSettings.WebAttribute, on: bool) -> None: ...
    def setDefaultTextEncoding(self, encoding: str) -> None: ...
    def setFontFamily(self, which: PySide6.QtWebEngineCore.QWebEngineSettings.FontFamily, family: str) -> None: ...
    def setFontSize(self, type: PySide6.QtWebEngineCore.QWebEngineSettings.FontSize, size: int) -> None: ...
    def setImageAnimationPolicy(self, policy: PySide6.QtWebEngineCore.QWebEngineSettings.ImageAnimationPolicy) -> None: ...
    def setUnknownUrlSchemePolicy(self, policy: PySide6.QtWebEngineCore.QWebEngineSettings.UnknownUrlSchemePolicy) -> None: ...
    def testAttribute(self, attr: PySide6.QtWebEngineCore.QWebEngineSettings.WebAttribute) -> bool: ...
    def unknownUrlSchemePolicy(self) -> PySide6.QtWebEngineCore.QWebEngineSettings.UnknownUrlSchemePolicy: ...


class QWebEngineUrlRequestInfo(Shiboken.Object):

    class NavigationType(enum.Enum):

        NavigationTypeLink       : QWebEngineUrlRequestInfo.NavigationType = ... # 0x0
        NavigationTypeTyped      : QWebEngineUrlRequestInfo.NavigationType = ... # 0x1
        NavigationTypeFormSubmitted: QWebEngineUrlRequestInfo.NavigationType = ... # 0x2
        NavigationTypeBackForward: QWebEngineUrlRequestInfo.NavigationType = ... # 0x3
        NavigationTypeReload     : QWebEngineUrlRequestInfo.NavigationType = ... # 0x4
        NavigationTypeOther      : QWebEngineUrlRequestInfo.NavigationType = ... # 0x5
        NavigationTypeRedirect   : QWebEngineUrlRequestInfo.NavigationType = ... # 0x6

    class ResourceType(enum.Enum):

        ResourceTypeMainFrame    : QWebEngineUrlRequestInfo.ResourceType = ... # 0x0
        ResourceTypeSubFrame     : QWebEngineUrlRequestInfo.ResourceType = ... # 0x1
        ResourceTypeStylesheet   : QWebEngineUrlRequestInfo.ResourceType = ... # 0x2
        ResourceTypeScript       : QWebEngineUrlRequestInfo.ResourceType = ... # 0x3
        ResourceTypeImage        : QWebEngineUrlRequestInfo.ResourceType = ... # 0x4
        ResourceTypeFontResource : QWebEngineUrlRequestInfo.ResourceType = ... # 0x5
        ResourceTypeSubResource  : QWebEngineUrlRequestInfo.ResourceType = ... # 0x6
        ResourceTypeObject       : QWebEngineUrlRequestInfo.ResourceType = ... # 0x7
        ResourceTypeMedia        : QWebEngineUrlRequestInfo.ResourceType = ... # 0x8
        ResourceTypeWorker       : QWebEngineUrlRequestInfo.ResourceType = ... # 0x9
        ResourceTypeSharedWorker : QWebEngineUrlRequestInfo.ResourceType = ... # 0xa
        ResourceTypePrefetch     : QWebEngineUrlRequestInfo.ResourceType = ... # 0xb
        ResourceTypeFavicon      : QWebEngineUrlRequestInfo.ResourceType = ... # 0xc
        ResourceTypeXhr          : QWebEngineUrlRequestInfo.ResourceType = ... # 0xd
        ResourceTypePing         : QWebEngineUrlRequestInfo.ResourceType = ... # 0xe
        ResourceTypeServiceWorker: QWebEngineUrlRequestInfo.ResourceType = ... # 0xf
        ResourceTypeCspReport    : QWebEngineUrlRequestInfo.ResourceType = ... # 0x10
        ResourceTypePluginResource: QWebEngineUrlRequestInfo.ResourceType = ... # 0x11
        ResourceTypeNavigationPreloadMainFrame: QWebEngineUrlRequestInfo.ResourceType = ... # 0x13
        ResourceTypeNavigationPreloadSubFrame: QWebEngineUrlRequestInfo.ResourceType = ... # 0x14
        ResourceTypeJson         : QWebEngineUrlRequestInfo.ResourceType = ... # 0x15
        ResourceTypeLast         : QWebEngineUrlRequestInfo.ResourceType = ... # 0x15
        ResourceTypeWebSocket    : QWebEngineUrlRequestInfo.ResourceType = ... # 0xfe
        ResourceTypeUnknown      : QWebEngineUrlRequestInfo.ResourceType = ... # 0xff


    def block(self, shouldBlock: bool) -> None: ...
    def changed(self) -> bool: ...
    def firstPartyUrl(self) -> PySide6.QtCore.QUrl: ...
    def httpHeaders(self) -> typing.Dict[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]: ...
    def initiator(self) -> PySide6.QtCore.QUrl: ...
    def navigationType(self) -> PySide6.QtWebEngineCore.QWebEngineUrlRequestInfo.NavigationType: ...
    def redirect(self, url: PySide6.QtCore.QUrl | str) -> None: ...
    def requestBody(self) -> PySide6.QtCore.QIODevice: ...
    def requestMethod(self) -> PySide6.QtCore.QByteArray: ...
    def requestUrl(self) -> PySide6.QtCore.QUrl: ...
    def resourceType(self) -> PySide6.QtWebEngineCore.QWebEngineUrlRequestInfo.ResourceType: ...
    def setHttpHeader(self, name: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, value: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview) -> None: ...


class QWebEngineUrlRequestInterceptor(PySide6.QtCore.QObject):

    def __init__(self, p: PySide6.QtCore.QObject | None= ...) -> None: ...

    def interceptRequest(self, info: PySide6.QtWebEngineCore.QWebEngineUrlRequestInfo) -> None: ...


class QWebEngineUrlRequestJob(PySide6.QtCore.QObject):

    class Error(enum.Enum):

        NoError                  : QWebEngineUrlRequestJob.Error = ... # 0x0
        UrlNotFound              : QWebEngineUrlRequestJob.Error = ... # 0x1
        UrlInvalid               : QWebEngineUrlRequestJob.Error = ... # 0x2
        RequestAborted           : QWebEngineUrlRequestJob.Error = ... # 0x3
        RequestDenied            : QWebEngineUrlRequestJob.Error = ... # 0x4
        RequestFailed            : QWebEngineUrlRequestJob.Error = ... # 0x5


    def fail(self, error: PySide6.QtWebEngineCore.QWebEngineUrlRequestJob.Error) -> None: ...
    def initiator(self) -> PySide6.QtCore.QUrl: ...
    def redirect(self, url: PySide6.QtCore.QUrl | str) -> None: ...
    def reply(self, contentType: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, device: PySide6.QtCore.QIODevice) -> None: ...
    def requestBody(self) -> PySide6.QtCore.QIODevice: ...
    def requestHeaders(self) -> typing.Dict[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]: ...
    def requestMethod(self) -> PySide6.QtCore.QByteArray: ...
    def requestUrl(self) -> PySide6.QtCore.QUrl: ...
    def setAdditionalResponseHeaders(self, additionalResponseHeaders: typing.Dict[PySide6.QtCore.QByteArray, PySide6.QtCore.QByteArray]) -> None: ...


class QWebEngineUrlScheme(Shiboken.Object):

    class Flag(enum.Flag):

        SecureScheme             : QWebEngineUrlScheme.Flag = ... # 0x1
        LocalScheme              : QWebEngineUrlScheme.Flag = ... # 0x2
        LocalAccessAllowed       : QWebEngineUrlScheme.Flag = ... # 0x4
        NoAccessAllowed          : QWebEngineUrlScheme.Flag = ... # 0x8
        ServiceWorkersAllowed    : QWebEngineUrlScheme.Flag = ... # 0x10
        ViewSourceAllowed        : QWebEngineUrlScheme.Flag = ... # 0x20
        ContentSecurityPolicyIgnored: QWebEngineUrlScheme.Flag = ... # 0x40
        CorsEnabled              : QWebEngineUrlScheme.Flag = ... # 0x80
        FetchApiAllowed          : QWebEngineUrlScheme.Flag = ... # 0x100

    class SpecialPort(enum.Enum):

        PortUnspecified          : QWebEngineUrlScheme.SpecialPort = ... # -0x1

    class Syntax(enum.Enum):

        HostPortAndUserInformation: QWebEngineUrlScheme.Syntax = ... # 0x0
        HostAndPort              : QWebEngineUrlScheme.Syntax = ... # 0x1
        Host                     : QWebEngineUrlScheme.Syntax = ... # 0x2
        Path                     : QWebEngineUrlScheme.Syntax = ... # 0x3


    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, name: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview) -> None: ...
    @typing.overload
    def __init__(self, that: PySide6.QtWebEngineCore.QWebEngineUrlScheme) -> None: ...

    @staticmethod
    def __copy__() -> None: ...
    def defaultPort(self) -> int: ...
    def flags(self) -> PySide6.QtWebEngineCore.QWebEngineUrlScheme.Flag: ...
    def name(self) -> PySide6.QtCore.QByteArray: ...
    @staticmethod
    def registerScheme(scheme: PySide6.QtWebEngineCore.QWebEngineUrlScheme) -> None: ...
    @staticmethod
    def schemeByName(name: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview) -> PySide6.QtWebEngineCore.QWebEngineUrlScheme: ...
    def setDefaultPort(self, newValue: int) -> None: ...
    def setFlags(self, newValue: PySide6.QtWebEngineCore.QWebEngineUrlScheme.Flag) -> None: ...
    def setName(self, newValue: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview) -> None: ...
    def setSyntax(self, newValue: PySide6.QtWebEngineCore.QWebEngineUrlScheme.Syntax) -> None: ...
    def syntax(self) -> PySide6.QtWebEngineCore.QWebEngineUrlScheme.Syntax: ...


class QWebEngineUrlSchemeHandler(PySide6.QtCore.QObject):

    def __init__(self, parent: PySide6.QtCore.QObject | None= ...) -> None: ...

    def requestStarted(self, arg__1: PySide6.QtWebEngineCore.QWebEngineUrlRequestJob) -> None: ...


class QWebEngineWebAuthPinRequest(Shiboken.Object):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, QWebEngineWebAuthPinRequest: PySide6.QtWebEngineCore.QWebEngineWebAuthPinRequest) -> None: ...

    @staticmethod
    def __copy__() -> None: ...


class QWebEngineWebAuthUxRequest(PySide6.QtCore.QObject):

    stateChanged             : typing.ClassVar[Signal] = ... # stateChanged(QWebEngineWebAuthUxRequest::WebAuthUxState)

    class PinEntryError(enum.Enum):

        NoError                  : QWebEngineWebAuthUxRequest.PinEntryError = ... # 0x0
        InternalUvLocked         : QWebEngineWebAuthUxRequest.PinEntryError = ... # 0x1
        WrongPin                 : QWebEngineWebAuthUxRequest.PinEntryError = ... # 0x2
        TooShort                 : QWebEngineWebAuthUxRequest.PinEntryError = ... # 0x3
        InvalidCharacters        : QWebEngineWebAuthUxRequest.PinEntryError = ... # 0x4
        SameAsCurrentPin         : QWebEngineWebAuthUxRequest.PinEntryError = ... # 0x5

    class PinEntryReason(enum.Enum):

        Set                      : QWebEngineWebAuthUxRequest.PinEntryReason = ... # 0x0
        Change                   : QWebEngineWebAuthUxRequest.PinEntryReason = ... # 0x1
        Challenge                : QWebEngineWebAuthUxRequest.PinEntryReason = ... # 0x2

    class RequestFailureReason(enum.Enum):

        Timeout                  : QWebEngineWebAuthUxRequest.RequestFailureReason = ... # 0x0
        KeyNotRegistered         : QWebEngineWebAuthUxRequest.RequestFailureReason = ... # 0x1
        KeyAlreadyRegistered     : QWebEngineWebAuthUxRequest.RequestFailureReason = ... # 0x2
        SoftPinBlock             : QWebEngineWebAuthUxRequest.RequestFailureReason = ... # 0x3
        HardPinBlock             : QWebEngineWebAuthUxRequest.RequestFailureReason = ... # 0x4
        AuthenticatorRemovedDuringPinEntry: QWebEngineWebAuthUxRequest.RequestFailureReason = ... # 0x5
        AuthenticatorMissingResidentKeys: QWebEngineWebAuthUxRequest.RequestFailureReason = ... # 0x6
        AuthenticatorMissingUserVerification: QWebEngineWebAuthUxRequest.RequestFailureReason = ... # 0x7
        AuthenticatorMissingLargeBlob: QWebEngineWebAuthUxRequest.RequestFailureReason = ... # 0x8
        NoCommonAlgorithms       : QWebEngineWebAuthUxRequest.RequestFailureReason = ... # 0x9
        StorageFull              : QWebEngineWebAuthUxRequest.RequestFailureReason = ... # 0xa
        UserConsentDenied        : QWebEngineWebAuthUxRequest.RequestFailureReason = ... # 0xb
        WinUserCancelled         : QWebEngineWebAuthUxRequest.RequestFailureReason = ... # 0xc

    class WebAuthUxState(enum.Enum):

        NotStarted               : QWebEngineWebAuthUxRequest.WebAuthUxState = ... # 0x0
        SelectAccount            : QWebEngineWebAuthUxRequest.WebAuthUxState = ... # 0x1
        CollectPin               : QWebEngineWebAuthUxRequest.WebAuthUxState = ... # 0x2
        FinishTokenCollection    : QWebEngineWebAuthUxRequest.WebAuthUxState = ... # 0x3
        RequestFailed            : QWebEngineWebAuthUxRequest.WebAuthUxState = ... # 0x4
        Cancelled                : QWebEngineWebAuthUxRequest.WebAuthUxState = ... # 0x5
        Completed                : QWebEngineWebAuthUxRequest.WebAuthUxState = ... # 0x6


    def cancel(self) -> None: ...
    def pinRequest(self) -> PySide6.QtWebEngineCore.QWebEngineWebAuthPinRequest: ...
    def relyingPartyId(self) -> str: ...
    def requestFailureReason(self) -> PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.RequestFailureReason: ...
    def retry(self) -> None: ...
    def setPin(self, pin: str) -> None: ...
    def setSelectedAccount(self, selectedAccount: str) -> None: ...
    def state(self) -> PySide6.QtWebEngineCore.QWebEngineWebAuthUxRequest.WebAuthUxState: ...
    def userNames(self) -> typing.List[str]: ...


def qWebEngineChromiumSecurityPatchVersion() -> bytes | bytearray | memoryview: ...
def qWebEngineChromiumVersion() -> bytes | bytearray | memoryview: ...
def qWebEngineVersion() -> bytes | bytearray | memoryview: ...


# eof
